@@ -772,7 +772,7 @@ int cFileArchive::Read(void* pDest, int count)
             int32 dummy;
             for (i = count; ; i -= sizeof(int32))
             {
-                if (i < sizeof(int32))
+                if (i < (int)sizeof(int32))
                 {
                     if (i > 0)
 					    mCurrentFile.Read( &dummy, i );
