@@ -61,8 +61,14 @@
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/param.h>
-#include <sys/ustat.h>
-#include <wchar.h>
+#if IS_BSD
+# include <sys/mount.h>
+# define _TWNBITSMAJOR 8
+#else
+# include <sys/ustat.h>
+# include <wchar.h>
+# include <sys/sysmacros.h>
+#endif
 #include <sys/utsname.h>
 #include <pwd.h>
 #include <sys/socket.h>
@@ -70,14 +76,13 @@
 #include <netinet/in.h>
 #include <grp.h>
 #include <fcntl.h>
-#include <sys/sysmacros.h>
 #include <errno.h>
 
 // commented out definition of _TWNBITSMAJOR because we should use the
 // makedev macro in sys/sysmacros.h for portability. 
 // except linux has the body of sysmacros.h commented out. why?
 // -jeb 7/26/99
-#if IS_LINUX
+#if IS_LINUX && !IS_BSD
 #include <sys/statfs.h>
 #define _TWNBITSMAJOR 8
 #endif //IS_LINUX
