@@ -503,7 +503,8 @@ void cHierDatabaseIter::CreateEntry( const TSTRING& name ) //throw (eArchive, eH
 	{
         if( 0 == Compare( mIter->mName.c_str(), newEntry.mName.c_str() ) )
         {
-            throw eHierDbDupeName( name );
+          return;
+          //throw eHierDbDupeName( name );
         }
 	}
 
