@@ -458,8 +458,8 @@ void cTWCmdLineUtil::VerifyPolicy( cGenreSpecListVector& genreSpecList, cFCOData
 ////////////////////////////////////////////////////////////////////////////////
 static void GetEmailRecipients(std::vector<TSTRING> &vstrRecipients, 
                                const cFCOReport& report,
-                               const TSTRING& globalEmail)
-{
+                               const cTWModeCommon *modeCommon) {
+
   // loop through all generes
   cFCOReportGenreIter genreIter(report);
   for (genreIter.SeekBegin(); !genreIter.Done(); genreIter.Next()) {
@@ -482,21 +482,29 @@ static void GetEmailRecipients(std::vector<TSTRING> &vstrRecipients,
                       vstrRecipients.end(),
                       address);
 
-        if (i != vstrRecipients.end())
+        if (i == vstrRecipients.end()) {
           vstrRecipients.push_back(address);
+        }
 
       }
     }
   }
+}
+
+
+static void GetGlobalEmailRecipients(std::vector<TSTRING> &vstrRecipients, 
+                                     const cFCOReport& report,
+                                     const cTWModeCommon *modeCommon) {
+
 
   // let's check for global emailto's...
   //
-  if (globalEmail.length() != 0) {
+  if (modeCommon->mGlobalEmail.length() != 0) {
 
     std::vector<TSTRING> addys;
     const std::string delims = ";,";
 
-    cStringUtil::splitstring(addys, globalEmail, delims);
+    cStringUtil::splitstring(addys, modeCommon->mGlobalEmail, delims);
     
     while (!addys.empty()) {
 
@@ -519,6 +527,7 @@ static void GetEmailRecipients(std::vector<TSTRING> &vstrRecipients,
 
     }
   }
+
 }
 
 
@@ -527,23 +536,25 @@ static void GetEmailRecipients(std::vector<TSTRING> &vstrRecipients,
 // EmailReportTo - send only the relevant portions of the report the address
 //
 ///////////////////////////////////////////////////////////////////////////////
-static bool EmailReportTo(const TSTRING &toAddress, const cFCOReportHeader& header, const cFCOReport& report, const cTWModeCommon *modeCommon)
+static bool EmailReportTo(const TSTRING &toAddress, const cFCOReportHeader& header, const cFCOReport& report, 
+                          const cTWModeCommon *modeCommon,
+                          const bool bForceFullReport)
 {
-   std::auto_ptr<cMailMessage> reportMail;
+  std::auto_ptr<cMailMessage> reportMail;
 
-   // allocate the right kind of emailer object based on what came out of the config file.
-   switch (modeCommon->mMailMethod) 
-   {
-   default:
+  // allocate the right kind of emailer object based on what came out of the config file.
+  switch (modeCommon->mMailMethod) 
+    {
+    default:
       ASSERT(false);
       return false;
-   case cMailMessage::MAIL_BY_SMTP:
+    case cMailMessage::MAIL_BY_SMTP:
       reportMail = std::auto_ptr<cMailMessage>(new cSMTPMailMessage(modeCommon->mSmtpHost, modeCommon->mSmtpPort));
       break;
-   case cMailMessage::MAIL_BY_PIPE:
+    case cMailMessage::MAIL_BY_PIPE:
       reportMail = std::auto_ptr<cMailMessage>(new cPipedMailMessage(modeCommon->mMailProgram));
       break;
-   case cMailMessage::MAIL_BY_MAPI:
+    case cMailMessage::MAIL_BY_MAPI:
 #if SUPPORTS_MAPI
       reportMail = std::auto_ptr<cMailMessage>(new cMAPIMailMessage);
       break;
@@ -551,13 +562,13 @@ static bool EmailReportTo(const TSTRING &toAddress, const cFCOReportHeader& head
       ASSERT(false);
       return false;
 #endif
-   }
+    }
 
-   TSTRING strTempFilename;
+  TSTRING strTempFilename;
 
-   // send the report
-   try
-   {
+  // send the report
+  try
+    {
       //    we have to write the text report to a temporary file...
       iFSServices::GetInstance()->GetTempDirName( strTempFilename );
       strTempFilename += _T("tripwire-report-XXXXXX");
@@ -565,50 +576,71 @@ static bool EmailReportTo(const TSTRING &toAddress, const cFCOReportHeader& head
       strTempFilename += _T(".txt");
 
       //    print the report
-        cEmailReportViewer trv( header, report, toAddress );
+      cEmailReportViewer trv( header, report, toAddress, bForceFullReport );
       trv.PrintTextReport( strTempFilename, modeCommon->mEmailReportLevel );
 
-        //      format the subject line with number of violations and the most severe violation found
-        //      set up the cMailMessage class, and send it if they need it or want it
+      //      format the subject line with number of violations and the most severe violation found
+      //      set up the cMailMessage class, and send it if they need it or want it
       //    (Yes, it seems odd to generate the report, only to potentially delete it without sending it.)
       if ( trv.GetNumberViolations() > 0 || modeCommon->mMailNoViolations )
-      {
-         // print message that we're emailing to this specific recipient
-         iUserNotify::GetInstance()->Notify( iUserNotify::V_NORMAL, _T("%s %s\n"), 
-                                    TSS_GetString( cTripwire, tripwire::STR_EMAIL_REPORT_TO).c_str(), 
-                                                cDisplayEncoder::EncodeInline( toAddress ).c_str());
-         reportMail->AddRecipient(toAddress);
+        {
+          // print message that we're emailing to this specific recipient
+          iUserNotify::GetInstance()->Notify( iUserNotify::V_NORMAL, _T("%s %s\n"), 
+                                              TSS_GetString( cTripwire, tripwire::STR_EMAIL_REPORT_TO).c_str(), 
+                                              cDisplayEncoder::EncodeInline( toAddress ).c_str());
+          reportMail->AddRecipient(toAddress);
 
-            TSTRING machineName;
-            iFSServices::GetInstance()->GetMachineNameFullyQualified(machineName);
-            reportMail->SetFrom(TSS_GetString( cTripwire, tripwire::STR_EMAIL_FROM) + machineName);
-            reportMail->SetFromName(TSS_GetString(cTW, tw::STR_TSS_PRODUCT_NAME));
+          TSTRING machineName;
+          iFSServices::GetInstance()->GetMachineNameFullyQualified(machineName);
+          reportMail->SetFrom(TSS_GetString( cTripwire, tripwire::STR_EMAIL_FROM) + machineName);
+          reportMail->SetFromName(TSS_GetString(cTW, tw::STR_TSS_PRODUCT_NAME));
              
-         reportMail->SetSubject( trv.SingleLineReport() );
+          reportMail->SetSubject( trv.SingleLineReport() );
          
-            // don't attach a report if the user just requests a subject line
-            if( cTextReportViewer::SINGLE_LINE == modeCommon->mEmailReportLevel )
-                reportMail->SetBody( _T(" ") );
-            else
-                reportMail->AttachFile( strTempFilename.c_str() );
+          // don't attach a report if the user just requests a subject line
+          if( cTextReportViewer::SINGLE_LINE == modeCommon->mEmailReportLevel )
+            reportMail->SetBody( _T(" ") );
+          else
+            reportMail->AttachFile( strTempFilename.c_str() );
 
-         reportMail->Send();
-      }
+          reportMail->Send();
+        }
 
       //    delete temp file
       iFSServices::GetInstance()->FileDelete( strTempFilename );
-   }
-   catch(eError& e)
-   {
-        e.SetFatality( false ); // we want to continue from email errors, so make them non-fatal
+    }
+  catch(eError& e)
+    {
+      e.SetFatality( false ); // we want to continue from email errors, so make them non-fatal
       cTWUtil::PrintErrorMsg(e);
       TCERR << TSS_GetString( cTripwire, tripwire::STR_ERR_EMAIL_REPORT) << std::endl;
-       // delete temp file
-       iFSServices::GetInstance()->FileDelete( strTempFilename );
+      // delete temp file
+      iFSServices::GetInstance()->FileDelete( strTempFilename );
       return false;
-   }
+    }
 
-   return true;
+  return true;
+}
+
+
+static bool DoEmailReports(const std::vector<std::string> &vstrRecipients, 
+                           const cFCOReportHeader& header,
+                           const cFCOReport& report, 
+                           const cTWModeCommon *modeCommon,
+                           const bool bForceFullReport) {
+
+  // send each report out.
+  bool ret = true;
+  for (std::vector<std::string>::size_type i=0; i<vstrRecipients.size(); i++)
+    {
+      TSTRING addr;
+      cStringUtil::Convert(addr, vstrRecipients[i]);
+      bool success = EmailReportTo(addr, header, report, modeCommon, bForceFullReport);
+      if (!success)
+        ret = false;
+    }
+
+  return (ret);
 }
 
 
@@ -622,31 +654,43 @@ static bool EmailReportTo(const TSTRING &toAddress, const cFCOReportHeader& head
 bool cTWCmdLineUtil::EmailReport(const cFCOReportHeader& header, const cFCOReport& report, 
                                  const cTWModeCommon *modeCommon)
 {
-   // print message that says that we're emailing
-   iUserNotify::GetInstance()->Notify( iUserNotify::V_NORMAL, _T("%s\n"), 
-                              TSS_GetString( cTripwire, 
-                                             tripwire::STR_EMAIL_BEGIN).c_str());
+  // print message that says that we're emailing
+  iUserNotify::GetInstance()->Notify( iUserNotify::V_NORMAL, _T("%s\n"), 
+                                      TSS_GetString( cTripwire, 
+                                                     tripwire::STR_EMAIL_BEGIN).c_str());
 
-   // Get the list of recipients
-   std::vector<TSTRING> vstrRecipients;
-   GetEmailRecipients(vstrRecipients, report, modeCommon->mGlobalEmail);
-   if (vstrRecipients.size() == 0) 
-   {
-      // Send a message to the user, alerting them that no email has been sent.
-      iUserNotify::GetInstance()->Notify( iUserNotify::V_NORMAL, _T("%s\n"), 
-         TSS_GetString( cTripwire, tripwire::STR_NO_EMAIL_RECIPIENTS).c_str());
-      return false;
-   }
+  bool emailSent = false;
+  bool ret = true;
 
-   // send each report out.
-   bool ret = true;
-   for (std::vector<TSTRING>::size_type i=0; i<vstrRecipients.size(); i++)
-   {
-      bool success = EmailReportTo(vstrRecipients[i], header, report, modeCommon);
-      if (!success)
-         ret = false;
-   }
-   return ret;
+  // Get the list of recipients
+  std::vector<TSTRING> vstrRecipients;
+
+  GetEmailRecipients(vstrRecipients, report, modeCommon);
+  emailSent |= (vstrRecipients.size() != 0);
+
+  if (vstrRecipients.size() != 0)
+    ret = DoEmailReports(vstrRecipients, header, report, modeCommon, false);
+  
+  if (ret) { // if not, probably catostrophic
+
+    vstrRecipients.clear();
+    GetGlobalEmailRecipients(vstrRecipients, report, modeCommon);
+    emailSent |= (vstrRecipients.size() != 0);
+
+    if (vstrRecipients.size() != 0)
+      ret = DoEmailReports(vstrRecipients, header, report, modeCommon, true);
+      
+  }
+
+
+  if (!emailSent) {
+
+    // Send a message to the user, alerting them that no email has been sent.
+    iUserNotify::GetInstance()->Notify( iUserNotify::V_NORMAL, _T("%s\n"), 
+                                        TSS_GetString( cTripwire, tripwire::STR_NO_EMAIL_RECIPIENTS).c_str());
+  }
+  
+  return ret;
 }
 
 
