@@ -85,7 +85,9 @@
 #include <iomanip>
 #include <time.h>
 #include <fcntl.h>
-#include <wchar.h>
+#if !IS_BSD
+# include <wchar.h>
+#endif
 
 #if IS_UNIX
     #include <unistd.h>
@@ -1280,7 +1282,7 @@ void cTextReportViewer::OutputRulesSummary( const cFCOReportGenreIter& genreIter
                  << strSpecName;
 
         // if the name is too long, put it on its own line
-        if( strSpecName.length() >= specNameWidth )
+        if( strSpecName.length() >= (unsigned int)specNameWidth )
         {
             (*mpOut) << endl;            
             (*mpOut) << _T("  "); // indent
@@ -1493,7 +1495,7 @@ void cTextReportViewer::DisplayChangedProps( const iFCO* const pfcoOld, const iF
             // if old value would run into this value, we need to put this value
             // on the next line (but in the same column).  don't output
             // value but position "cursor" in the correct place
-            if( strOldValue.length() >= attrValueWidth )
+            if( strOldValue.length() >= (unsigned int)attrValueWidth )
             {
                 (*mpOut) << endl;
                 (*mpOut) << setw( marginWidth )     << _T("");
@@ -1768,10 +1770,11 @@ void cTextReportViewer::EatSection()
 //
 //=========================================================================
 
-cEmailReportViewer::cEmailReportViewer( const cFCOReportHeader& h, const cFCOReport& r, const TSTRING &address)
-    :cTextReportViewer( h, r )
+cEmailReportViewer::cEmailReportViewer( const cFCOReportHeader& h, const cFCOReport& r, 
+                                        const TSTRING &address, bool bForceFullReport /*= false */)
+  : cTextReportViewer( h, r ), mbForceFullReport(bForceFullReport)
 {
-	mAddress = address;
+    mAddress = address;
 }
 
 bool cEmailReportViewer::IgnoreThisSpec(const cFCOSpecAttr *attr)
@@ -1779,6 +1782,10 @@ bool cEmailReportViewer::IgnoreThisSpec(const cFCOSpecAttr *attr)
 	// IgnoreThisSpec - returns false if the email address is specified
 	// for the given spec attributes.
 
+  if (mbForceFullReport)
+    return false;
+
+
 	// loop through all email addresses for this spec
 	cFCOSpecAttrEmailIter emailIter(*attr);
 	for(emailIter.SeekBegin(); ! emailIter.Done(); emailIter.Next())
@@ -1937,7 +1944,7 @@ void cTextReportViewer::GetChar()
 
     // initialize mCurrentChar
     mCurrentCharSize = 0;
-    for( int i = 0; i < sizeof( mCurrentChar ); i++ )
+    for( int i = 0; i < (int)sizeof( mCurrentChar ); i++ )
         mCurrentChar[i] = 0;
 
     static const std::istream::char_type eof = 
